# Change Log

## [2.0.0]

* Renamed `image` module to `hist`.
* New objects `Histogram`, `SparseHistogram`, and `Histogram1D`, which store histogram values and bin coords/edges.
* Updated proplot dependency to ultraplot.
* Added empty `distance` module.
* Created `density` module for density estimation.
* Removed `ap` module and rewrote `cov` module.
* Renamed `dist` to `distributions` module.
* Updated `plot` module to process `Histogram` objects.
* Made functions and classes available from top-level module.
* Fixed various bugs.


## [1.0.2]

* Added cubehelix colormap function.
* Added `utils.coords_to_edges` and `utils.edges_to_coords`.
* Added `image.Image` and `image.Profile`.

## [1.0.1]

* Added `plot.plot_points` (calls `plot.points.plot`).
* Added `plot.plot_points` (calls `plot.points.plot`).
* Added function `cov.normalization_matrix_block_diag`).
* Fixed typos in `points.covariance_matrix` `points.correlation_matrix`, `image.covariance_matrix` `image.correlation_matrix`.
* Fixed typo in `image.sample`.

  
## [1.0.0]

* Initial release

